===============================================================================================
``psyclone.domain.gocean.transformations.gocean_move_iteration_boundaries_inside_kernel_trans``
===============================================================================================

.. automodule:: psyclone.domain.gocean.transformations.gocean_move_iteration_boundaries_inside_kernel_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.gocean.transformations.gocean_move_iteration_boundaries_inside_kernel_trans


Classes
=======

- :py:class:`GOMoveIterationBoundariesInsideKernelTrans`:
  Provides a transformation that moves iteration boundaries that are


.. autoclass:: GOMoveIterationBoundariesInsideKernelTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: GOMoveIterationBoundariesInsideKernelTrans
      :parts: 1
